#
# spec file for package guile-ssh
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         libsoname lib%{name}18

Name:           guile-ssh
Version:        0.18.0
Release:        1.1
Summary:        SSH protocol access from Guile
License:        GPL-3.0-or-later
Group:          Development/Libraries/Other
URL:            https://github.com/artyom-poptsov/guile-ssh
Source0:        https://github.com/artyom-poptsov/%{name}/archive/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  guile-devel
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libssh) >= 0.8.0
Requires:       guile >= 2.0.9
Requires:       libssh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Guile-SSH is a library that provides access to the SSH protocol for programs written in GNU Guile interpreter.

%package -n %{libsoname}
Summary:        SSH protocol access from Guile
Group:          System/Libraries

%description -n %{libsoname}
The shared libraries for guile-ssh, which let you access the SSH protocol from
Guile.

%package devel
Summary:        Development files for Guile-SSH
Group:          Development/Libraries/Other
Requires:       %{libsoname} = %{version}-%{release}

%description devel
The libraries and header files for developing applications that use guile-ssh.

%prep
%setup -q

%build
autoreconf -vfi
%configure \
	   --disable-silent-rules \
     --disable-static

make %{?_smp_mflags}

%install
%make_install
# install executable examples to /usr/share/guile-ssh/examples
install -t %{buildroot}%{_datadir}/guile-ssh/examples examples/sssh*.scm
rm -rvf %{buildroot}%{_bindir}
# remove static library
find %{buildroot} -name '*.la' -delete

%post   -n %{libsoname} -p /sbin/ldconfig
%postun -n %{libsoname} -p /sbin/ldconfig

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/guile-ssh.info.gz

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/guile-ssh.info.gz

%files -n %{libsoname}
%defattr(-,root,root)
%{_libdir}/libguile-ssh.so.*

%files devel
%defattr(-,root,root)
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/guile
%{_libdir}/libguile-ssh.so
%{_datadir}/guile
%{_datadir}/guile-ssh
%{_infodir}/guile-ssh.info.gz
# make example scripts executable
%attr(755,root,root) %{_datadir}/guile-ssh/examples/*.scm
%attr(755,root,root) %{_datadir}/guile-ssh/examples/echo/*.scm
%attr(755,root,root) %{_datadir}/guile-ssh/examples/rpc/*.scm

%changelog
* Wed Dec  4 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 0.18.0
  * Change (ssh popen) procedures behavior
  * make-session now handles #:config set to #f properly
  * session-func.c: Fix compile error caused by bool identifier
  * session-func.c: Fix compilation with libssh < 0.8.3
  * session-func.c: Add compilation warnings for missing options
  * Drop support for libssh versions older than 0.8.0
- Update to 0.17.0
  * make-session now loads config file before setting options
  * session-set! now allows to set rsa-min-size
- Update to 0.16.4:
  * private-key-from-file now allows to read encrypted keys
* Sun Jun 18 2023 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 0.16.3:
  * Fix Guile-SSH/libssh channel leak
  * Bugfix in test "string->public-key, ECDSA"
  * Disable the tests that require DSA algorithm by default
  * Add '--enable-dsa' Autoconf option
  * (ssh version): 'dsa-support?': New procedure
* Fri Sep 30 2022 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 0.16.0:
  * Fix cross-compilation
  * New API: SFTP directory traversal
  * Fix session garbage collecting errors
  * Fix segfaults that occur on session closing
  * Add GNU Guix package definition to the repository
  * Bump library version to 14:0:0 according to libtool rules
  * Remove requirement for whereis command
  * API change: OpenSSH agent procedures are now in (ssh agent)
  * API change: Remove 'sftp-init' from (ssh sftp)
  * Guile-SSH channels are now explicilty blocking by default
  * Fix random segfaults due to libssh logging
  * Fix "random" erorrs and segfaults in channels
  * Fix test failures due to 'primitive-fork-calls
  * Fix the tests for Guile 3.0.7 & 3.0.5
  * Guile-SSH builing process now less verbose
- Update library (soname) to 14
* Fri Nov  6 2020 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 0.13.1:
  * API change: 'call-with-ssh-forward' does not start a thread
  * API change: add 'nodelay' option for Guile-SSH sessions
  * Fix some random segfaults in the channel and session code
  * Add support for macOS
  * Disable libguile-ssh static library
  * Don't use deprecated libssh procedures
  * Fix segfaults on GC'ing
  * Channels procedures now check if the parent session is alive
  * Changes in documentation
- Update library to 13
* Tue Jan  7 2020 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 0.12.0:
  * API change: Implement new version of the RREPL API
  * New module: (ssh agent)
  * Make build with Guile 3.0 possible
  * Remove bundled SRFI-64, as it's include in Guile since 2.0.12.
  * Guile-SSH should allow cross-compilation
  * New procedure 'userauth-gssapi!' in (ssh auth)
  * Fix a segfault in 'libguile-ssh'
  * Fix building with libssh 0.8
  * Fix failing tests and some generic compilation fixes
- Increase libsoname to 12
- Remove patches:
  * 0001-libguile-ssh-Remove-ssh_threads-from-LDFLAGS.patch: included
    in the release.
* Mon Feb 25 2019 jbrielmaier@suse.de
- set libssh minimum version to 0.6.4
* Mon Feb 25 2019 jbrielmaier@suse.de
- enable the libssh_threads patch also on Leap/SLE 15.1, as
  libssh_threads is there also in libssh
* Wed Sep 12 2018 jbrielmaier@suse.de
- don't link against libssh_threads anymore, as it gots removed in
  libssh 0.8. gh#artyom-poptsov/guile-ssh#9
  Add and use it on Tumbleweed and Factory:
  * 0001-libguile-ssh-Remove-ssh_threads-from-LDFLAGS.patch
* Mon Jul 16 2018 jbrielmaier@suse.de
- correct installation of info files
* Sat Jul 14 2018 jengelh@inai.de
- Update summaries.
* Thu Jun 28 2018 jbrielmaier@suse.de
- libguile-ssh subpackage for shared libraries
- devel depend on libguile-ssh
- improve descriptions
- install example scripts to correct place and make them executable
- don't install static library
- install info file
* Wed May 30 2018 jbrielmaier@suse.de
- inital version of guile-ssh 0.11.3
